// 
// This example program calculates the rate for each
// reaction in the Reaclib file at 1 GK.
// 

#include <cmath>
#include <cstdio>

#include "reaclibReader/NuclideSearch.h"
#include "reaclibReader/reaclibReader.h"

using namespace std;

int main() {
	char nucFile[] = "example_data/nuclides.xml";
	const char reaclibFile[] = "example_data/ReaclibV1.0";
	int t9 = 1; // Temperature = 1 GK
	
	// Load the nuclide list
	NuclideSearch *nuclideSearch = NuclideSearch::newInstance();
	nuclideSearch->loadNuclideFile(nucFile);
	
	// Load a Reaclib file
	ReaclibReader reader;
	reader.LoadREACLIB(reaclibFile);
	
	// Loop through the rates
	for(int i = 0; i < reader.getRateSize(); i += 1) {
		ReaclibRate *rate = reader.getRate(i);
		
		// Loop through the versions of that rate
		for(int j = 0; j < rate->getVersionSize(); j += 1) {
			ReaclibVer *ver = rate->getVer(j);
			
			// Loop through the sets (fit parameters) of this version to calculate the
			// reaction rate (rr).
			double rr = 0;
			for(int k = 0; k < ver->getSetSize(); k += 1) {
				ReaclibSet *set = ver->getSet(k);
				
				// Calculate one term of the form:
				// exp(a0 + a1/T9 + a2/T9^(1/3) + a3*T9^(1/3) + a4*T9 + a5*T9^(5/3) + a6*ln(T9))
				double tmp = 0;
				tmp += set->getA0();
				tmp += set->getA1() / t9;
				tmp += set->getA2() / pow(t9, 1.0f/3.0f);
				tmp += set->getA3() * pow(t9, 1.0f/3.0f);
				tmp += set->getA4() * t9;
				tmp += set->getA5() * pow(t9, 5.0f/3.0f);
				tmp += set->getA6() * log(t9);
				tmp = exp(tmp);
				rr += tmp;
			}
			
			// Show the reaction rate for that version of the reaction
			printf("%.3e = rate at 1 GK of %s (v%d)\n", rr, rate->getEqn(), j);
		}
	}
}
